"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import requests as requests_http
from ..shared import deprecatedeventresult as shared_deprecatedeventresult
from typing import Optional



@dataclasses.dataclass
class DeprecateEventRequest:
    event_id: str = dataclasses.field(metadata={'path_param': { 'field_name': 'event_id', 'style': 'simple', 'explode': False }})
    r"""Identical to the `idempotency_key` provided on event ingestion. Uniquely identifies an event in the system."""
    




@dataclasses.dataclass
class DeprecateEventResponse:
    content_type: str = dataclasses.field()
    r"""HTTP response content type for this operation"""
    status_code: int = dataclasses.field()
    r"""HTTP response status code for this operation"""
    deprecated_event_result: Optional[shared_deprecatedeventresult.DeprecatedEventResult] = dataclasses.field(default=None)
    r"""OK"""
    raw_response: Optional[requests_http.Response] = dataclasses.field(default=None)
    r"""Raw HTTP response; suitable for custom response parsing"""
    

